import os, sys
import shutil

from lonely import cmd, system
from lonely.core import lonely

class Go(object):
    def __init__(self):
        self.oss = ("linux", "darwin")
        self.archs = {"x86_64":"amd64", "aarch64":"arm64"}
        self.home = "%s/go" % lonely.home
        self.conf = [
            "# start:lonely:go\n",
            "export GOROOT=%s/go\n" % lonely.home,
            "export GOPATH=%s/.go\n" % system.home,
            "export GOBIN=$GOPATH/bin\n",
            "export PATH=$PATH:$GOROOT/bin\n",
            "export PATH=$PATH:$GOPATH/bin\n",
            "export GOPROXY=https://goproxy.cn,direct\n",
            "#export GOPROXY=https://goproxy.io,direct #spare-备用\n",
            "# end:lonely:go\n",
        ]
    
    def check(self):
        if system.os not in self.oss:
            print("Unsupported os: %s" % system.os)
            sys.exit(1)
        if system.arch not in self.archs:
            print("Unsupported arch: %s" % system.arch)
            sys.exit(1)

    def install(self):
        self.check()
        if cmd.command("go version", stderr=cmd.DEVNULL).returncode == 0:
            print("go has been installed, please delete it first.")
            sys.exit(1)

        version = "1.15.6"
        go_file_name = "go%s.%s-%s.tar.gz" % (version, system.os, self.archs[system.arch])
        go_file = system.temp + "/" + go_file_name
        url = "https://golang.google.cn/dl/" + go_file_name

        lonely.mkdir()
        cmd.run([
            "wget -O %s %s" % (go_file, url),
            "tar -C %s -xzf %s" % (lonely.home, go_file),
        ], multi_command=True)
        self.env_add()
    
    def update(self):
        self.remove()
        self.install()

    def remove(self):
        self.check()
        lonely.access()
        if not os.path.exists(self.home):
            print("Directory does not exist: %s" % self.home)
            sys.exit(1)
        shutil.rmtree(self.home)
        self.env_del()
        
    def env_add(self):
        if not system.env_add(self.conf):
            sys.exit(1)
        
    def env_del(self):
        if not system.env_del(self.conf):
            sys.exit(1)



import os as _os
import platform

from lonely.cmd import command

def lsb_release():
    ret = command("cat /etc/openEuler-release", capture_output=True, print_out=False, print_err=False)
    if ret.returncode == 0:
        #print("success:", ret)
        if ret.stdout.lower().find("openeuler") > -1:
            return "openeuler"
        else:
            return "unknown"
    else:
        #print("failure:", ret)
        return "unknown"

os = platform.system().lower()
arch = platform.machine().lower()
release = lsb_release()

shell = _os.getenv('SHELL')
home = _os.getenv('HOME')

base = "/usr/local"
temp = "/tmp"

env_file = {
    "linux": "%s/.bashrc" % home,
    "darwin": "%s/.bash_profile" % home,
}
source_file = {
    "/bin/bash": env_file.get(os),
    "/bin/zsh": "%s/.zshrc" % home,
}

def source(file=None):
    if file is not None and isinstance(file, str) and len(file) > 0:
        return command("source %s" % file)
    else:
        sf = source_file.get(shell)
        if sf is not None:
            return command("source %s" % sf)
        else:
            return None

# todo: 优化空行间隔
def env_add(conf):
    if conf is None or type(conf) not in (type(()), type([])) or len(conf) < 2:
        return False
    
    if os not in env_file:
        print("Unsupported os: %s" % os)
        return False

    env_file_path = env_file[os]
    temp_file = env_file_path + ".tmp"
    start = conf[0]
    end = conf[len(conf)-1]
    flag = 0

    with open(env_file_path, "r", encoding="utf-8") as f1, open(temp_file, "w", encoding="utf-8") as f2:
        for line in f1:
            if flag == 0 and start in line:
                flag = 1
                continue
            if flag == 1 and end in line:
                flag = 2
                f2.write("\n")
                f2.writelines(conf)
                f2.write("\n")
                continue
            if flag in (0, 2):
                f2.write(line)
        if flag == 0:
            f2.write("\n")
            f2.writelines(conf)
            f2.write("\n")
        elif flag == 1:
            raise("env file syntax error, missing end. %s" % env_file_path)
        
    _os.remove(env_file_path)
    _os.rename(temp_file, env_file_path)
    # source() #todo: 无效的，子进程内 source，不会作用于父进程。
    return True

# todo: 优化空行间隔
def env_del(conf):
    if conf is None or type(conf) not in (type(()), type([])) or len(conf) < 2:
        return False
    
    if os not in env_file:
        print("Unsupported os: %s" % os)
        return False

    env_file_path = env_file[os]
    temp_file = env_file_path + ".tmp"
    start = conf[0]
    end = conf[len(conf)-1]
    flag = 0

    with open(env_file_path, "r", encoding="utf-8") as f1, open(temp_file, "w", encoding="utf-8") as f2:
        for line in f1:
            if flag == 0 and start in line:
                flag = 1
                continue
            if flag == 1 and end in line:
                flag = 2
                continue
            if flag in (0, 2):
                f2.write(line)
        if flag == 1:
            raise("env file syntax error, missing end. %s" % env_file_path)
        
    _os.remove(env_file_path)
    _os.rename(temp_file, env_file_path)
    # source() #todo: 无效的，子进程内 source，不会作用于父进程。
    return True



#!/usr/bin/python3

import time
import socket
import datetime
import platform

import psutil

print('-----------------------------CPU信息-------------------------------------')
# 查看cpu物理个数的信息
cpu_count = psutil.cpu_count(logical=False)
# CPU的使用率
cpu = (str(psutil.cpu_percent(1))) + '%'
print(u"物理CPU个数: %s  CUP使用率: %s" % (cpu_count, cpu))

print('-----------------------------内存信息-------------------------------------')
# 查看内存信息,剩余内存.free  总共.total
# round()函数方法为返回浮点数x的四舍五入值。
free = str(round(psutil.virtual_memory().free / (1024.0 * 1024.0 * 1024.0), 2))
total = str(round(psutil.virtual_memory().total / (1024.0 * 1024.0 * 1024.0), 2))
memory = int(psutil.virtual_memory().total - psutil.virtual_memory().free) / float(psutil.virtual_memory().total)
print(u"物理内存: %sG  剩余物理内存: %sG  物理内存使用率: %s%%" % (total, free, int(memory * 100)))

print('-----------------------------磁盘信息---------------------------------------')
disk = psutil.disk_usage("/")
total = int(disk.total / (1024.0 * 1024.0 * 1024.0))
free = int(disk.free / (1024.0 * 1024.0 * 1024.0))
print("总容量: %sG  可用容量: %sG" % (total, free))

print('-----------------------------网络信息---------------------------------------')
net = psutil.net_io_counters()
bytes_sent = '{0:.2f}Mb'.format(net.bytes_recv / 1024 / 1024)
bytes_rcvd = '{0:.2f}Mb'.format(net.bytes_sent / 1024 / 1024)
print(u"网卡接收流量: %s  网卡发送流量: %s" % (bytes_rcvd, bytes_sent))

print('-----------------------------系统信息-------------------------------------')
# 当前时间
now_time = time.strftime('%Y-%m-%d-%H:%M:%S', time.localtime(time.time()))
print("当前时间: %s" % now_time)

# 系统启动时间
print(u"系统启动时间: %s" % datetime.datetime.fromtimestamp(psutil.boot_time()).strftime("%Y-%m-%d %H:%M:%S"))

# 系统用户
users_count = len(psutil.users())
users_list = ",".join([u.name for u in psutil.users()])
print(u"登录用户: %s个，分别是 %s" % (users_count, users_list))

sys_system = platform.system()  # 系统类型
sys_platform = platform.platform()  # 操作系统名称及版本号，'Windows-10-10.0.17134-SP0'
sys_version = platform.version()  # 操作系统版本号，'10.0.17134'
sys_architecture = platform.architecture()  # 操作系统的位数，('64bit', 'WindowsPE')
sys_machine = platform.machine()  # 硬件架构，'AMD64'
sys_node = platform.node()  # 网络名称，'TDM'
sys_processor = platform.processor()  # 处理器信息，'Intel64 Family 6 Model 158 Stepping 9, GenuineIntel'
sys_uname = platform.uname()  # 包含上面所有的信息汇总，

print("系统类型: %s" % sys_system)
print("系统版本: %s" % sys_version)
print("硬件架构: %s" % sys_machine)
print("处理器信息: %s" % sys_processor)
print("网络名称: %s" % sys_node)


def get_host_ip():
    """
    查询本机ip地址
    :return: ip
    """
    try:
        s = socket.socket(socket.AF_INET, socket.SOCK_DGRAM)
        s.connect(('8.8.8.8', 80))
        ip = s.getsockname()[0]
    finally:
        s.close()
    return ip


if __name__ == '__main__':
    print("IP地址: %s" % get_host_ip())



import sys
import subprocess

PIPE = subprocess.PIPE
STDOUT = subprocess.STDOUT
DEVNULL = subprocess.DEVNULL

def run(*args, exit_code=True, multi_command=False, **kwargs):
    if multi_command and (isinstance(args[0], tuple) or isinstance(args[0], list)):
        rets = []
        for arg in args[0]:
            rets.append(command(arg, exit_code, **kwargs))
        return rets
    else:
        return command(*args, exit_code, **kwargs)

def command(*args, exit_code=False, print_out=True, print_err=True, **kwargs):
    if 'shell' not in kwargs:
        kwargs['shell'] = True
    if 'encoding' not in kwargs:
        kwargs['encoding'] = 'utf-8'

    ret = subprocess.run(*args, executable="/bin/bash", **kwargs)
    
    if print_out and ret.stdout is not None and len(ret.stdout) > 0:
        print(ret.stdout)
    if print_err and ret.stderr is not None and len(ret.stderr) > 0:
        print(ret.stderr)
    if exit_code and ret.returncode != 0:
        sys.exit(ret.returncode)
    return ret



import os, sys

from lonely import system, cmd

home = "/usr/local/lonely"

# 导入 apps 必须在 home 定义的后面，因为 app 包内依赖 lonely.home
from lonely.app import apps

def exist():
    return os.path.exists(home)

def mkdir():
    if not os.path.exists(home):
        access(system.base)
        os.mkdir(home)
    else:
        access(home)

def access(path=None):
    if path is None:
        path = home
    if not os.access(path, os.W_OK):
        print("Permission denied: %s" % path)
        sys.exit(1)

class Lonely(object):
    def version(self):
        print("lonely version 0.0.4")

    def install(self, app_name):
        app = apps.get(app_name)
        if app != None and hasattr(app, "install"):
            app.install()
        else:
            print("Unsupported app: %s" % app_name)
            sys.exit(1)

    def update(self, app_name):
        app = apps.get(app_name)
        if app != None and hasattr(app, "update"):
            app.update()
        else:
            print("Unsupported app: %s" % app_name)
            sys.exit(1)

    def remove(self, app_name):
        app = apps.get(app_name)
        if app != None and hasattr(app, "remove"):
            app.remove()
        else:
            print("Unsupported app: %s" % app_name)
            sys.exit(1)

    def env_add(self, app_name):
        app = apps.get(app_name)
        if app != None and hasattr(app, "env_add"):
            app.env_add()
        else:
            print("Unsupported app: %s" % app_name)
            sys.exit(1)

    def env_del(self, app_name):
        app = apps.get(app_name)
        if app != None and hasattr(app, "env_del"):
            app.env_del()
        else:
            print("Unsupported app: %s" % app_name)
            sys.exit(1)



#!/usr/bin/python3

import os
import setuptools
 
setuptools.setup(
    name='lonely',
    version='0.0.4',
    keywords='lonely tools',
    description='A lonely package management tool.',
    license='Apache',
    long_description=open(
        os.path.join(
            os.path.dirname(__file__),
            'README.rst'
        )
    ).read(),
    author='lonelypale', #替换为你的Pypi官网账户名
    author_email='lonelypale@126.com', #替换为你Pypi账户名绑定的邮箱
    url='https://github.com/lonelyPale/lonely', #这个地方为github项目地址，貌似非必须
    packages=setuptools.find_packages(),
    install_requires=['fire'],
    python_requires='>=3',
    #如果需要支持脚本方法运行，可以配置入口点
    entry_points={
        'console_scripts': [
            'lone = lonely.__main__:main'
        ]
    },
)



import sys

from lonely import cmd, system
from lonely.core import lonely

class YumRepo:
    def install(self):
            if system.os != "linux":
                print("Unsupported os: %s" % system.os)
                sys.exit(1)
            
            if system.arch != "x86_64" and system.arch != "aarch64":
                print("Unsupported arch: %s" % system.arch)
                sys.exit(1)
            
            if system.release != "openeuler":
                print("Unsupported release: %s" % system.release)
                sys.exit(1)
            
            url = ""
            if system.arch == "x86_64":
                url = "https://repo.huaweicloud.com/repository/conf/openeuler_x86_64.repo"
            elif system.arch == "aarch64":
                url = "https://repo.huaweicloud.com/repository/conf/openeuler_aarch64.repo"
            
            cmd.run([
                "wget -O /etc/yum.repos.d/openEulerOS.repo %s" % url,
                "yum clean all",
                "yum makecache",
            ], multi_command=True)
